@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.00";
+  $VERSION= "3.01";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -115,20 +115,6 @@ package Apache2::AMFWURFLFilterMemcached;
        $CommonLib->printLog("The AMF is not connected to the Memcached server: $serverMemCache.");
 	   ModPerl::Util::exit();      
    }
-  #if ($memd->get('ver')) {
-  #} else {
-  #          $CommonLib->printLog('It\'s the first time you use this memcached. Remember the other webservers with AMF installed for access to memcached MUST have the same configuration in httpd.conf');
-  #    	    $memd->set('ver', 'null');
-  #	        $memd->set('caplist', 'null');
-  #	        $memd->set('listall', 'null');
-  #	        $memd->set('RedirectTranscoderUrl','null');
-  #	        $memd->set('MobileVersionUrl','null');
-  #	        $memd->set('FullBrowserUrl','null');
-  #	        $memd->set('ResizeImageDirectory','null');
-  #}
-  #
-  # Define the cache system directory
-  #
   $memd->set('device_not_found', "id=device_not_found&device=false&device_claims_web_support=true&is_wireless_device=false");
   if ($ENV{MOBILE_HOME}) {
 	  &loadConfigFile("$ENV{MOBILE_HOME}/wurfl.xml");
@@ -169,6 +155,7 @@ sub loadConfigFile {
 				}
 			 } else {
 				$listall="true";
+				$CommonLib->printLog('CapabilityList not setted so the default value is "all"');
 			 }	
 	             
 	      	 if ($ENV{LoadWebPatch}) {
@@ -624,94 +611,7 @@ __END__
 	
 =head1 NAME
 
-Apache2::WURFLFilter - The module detects the mobile device and passes the WURFL capabilities on to the other web application as environment variables
-
-=head1 SYNOPSYS
-
-The configuration of V2.x of B<"Apache Mobile Filter"> is very simple thane V1.x, I have deprecated the intelliswitch method because I think that the filter is faster.
-
-Add this parameter into httpd.conf file:
-
-=over 4
-=item C<PerlSetEnv CacheDirectoryStore /tmp>
-
-=item C<PerlSetEnv CapabilityList max_image_width,j2me_midp_2_0> *
-
-=item C<PerlSetEnv WurflNetDownload true>***
-
-=item C<PerlSetEnv DownloadWurflURL http://downloads.sourceforge.net/wurfl/wurfl-latest.zip>****
-
-=item C<PerlSetEnv DownloadZipFile false>
-
-=item C<PerlSetEnv ResizeImageDirectory /transform>
-
-=item C<PerlSetEnv LoadWebPatch true>
-
-=item C<PerlSetEnv PatchWurflNetDownload true>
-
-=item C<PerlSetEnv PatchWurflUrl http://wurfl.sourceforge.net/web_browsers_patch.xml>
-
-=item C<PerlSetEnv MobileVersionUrl /cgi-bin/perl.html> ** (default is "none" that mean the filter pass through)
-
-=item C<PerlSetEnv FullBrowserUrl http://www.google.com> ** (default is "none" that mean the filter pass through)
-
-=item C<PerlSetEnv RedirectTranscoderUrl /transcoderpage.html> (default is "none" that mean the filter pass through)
-
-=item C<PerlSetEnv CookieCacheSystem true> (default is false, but for production mode is suggested to set in true) 
-
-=item C<PerlModule Apache2::WURFLFilter>
-
-=item C<PerlTransHandler +Apache2::WURFLFilter>
-
-=back
-
-* the field separator of each capability you want to consider in your mobile site is ",". Important you now can set ALL (default value) if you want that the filter managed all wurfl capabilities
-
-**if you put a relative url (for example "/path") the filter done an internal redirect, if you put a url redirect with protocol (for example "http:") the filter done a classic redirect
-
-***if this parameter is fault the filter try to read  the wurfl.xml file from MOBILE_HOME path
-
-***if you want to download directly the last version of WURFL.xml you can set the url parameter to http://downloads.sourceforge.net/wurfl/wurfl-latest.zip
-
-****if you put to true value you can detect a little bit more device, but for strange UA the method take  a lot of time 
-
-
-=head1 DESCRIPTION
-
-For this configuration you need to set this parameter
-
-=over 4	
-=item C<PerlSetEnv CacheDirectoryStore>: set where the AMF cache is located
-
-=item C<ConvertImage> (boolean): activate/deactivate the adaptation of images to the device
-
-=item C<ResizeImageDirectory>: where the new images are saved for cache system, remember this directory must be into docroot directory and also must be writeble from the server
-
-=item C<WurflNetDownload> (boolean): if you want to download WURFL xml directly from WURFL site or from an intranet URL (good to have only single point of Wurfl access), default is set to false
-
-=item C<DownloadWurflURL>: the url of WURFL DB to download**
-
-=item C<CapabilityList> : is the capability value you want to pass to you site
-
-=item C<MobileVersionUrl>: is the URL address of mobile version site *
-
-=item C<FullBrowserUrl>: is the URL address of PC version site *
-
-=item C<RedirectTranscoderURL>: the URL where you want to redirect the transcoder*
-
-=item C<LoadWebPatch> (boolean): if you want to use a wurfl patch file
-
-=item C<PatchWurflNetDownload>(boolean): if you want download the patch file
-
-=item C<PatchWurflUrl>: the URL of the patch file (is readed ony if PatchWurflNet is setted with true)
-
-=back
-
-*if you put a relative url (for example "/path") the filter done an internal redirect, if you put a url redirect with protocol (for example "http:") the filter done a classic redirect. If the parameter is not set the filter is a passthrough 
-
-**if you want to download directly the last version of WURFL.xml you can set the url parameter to http://downloads.sourceforge.net/wurfl/wurfl-latest.zip
-
-*** for more info about transcoder problem go to http://wurfl.sourceforge.net
+Apache2::AMFWURFLFilterMemcached - The module detects the mobile device and passes the WURFL capabilities on to the other web application as environment variables
 
 =head1 SEE ALSO
 
